@@ -15,6 +15,8 @@ from .emailActivities import EmailActivities
 from .dealActivities import DealActivities
 from .customobjects import CustomObjects
 from .campaigns import Campaigns
+from .addresses import Addresses
+from .brandings import Brandings
 
 class Client(object):
     BASE_URL = '{}/api/3'
@@ -38,6 +40,8 @@ class Client(object):
         self.dealActivities = DealActivities(self)
         self.customobjects = CustomObjects(self)
         self.campaigns = Campaigns(self)
+        self.addresses = Addresses(self)
+        self.brandings = Brandings(self)
 
     def _get(self, endpoint, **kwargs):
         return self._request('GET', endpoint, **kwargs)
